@@ -20,7 +20,7 @@ DataFrame grouped_df_impl(DataFrame data, SymbolVector symbols, bool drop, bool
   if (!symbols.size())
     stop("no variables to group by");
   if (build_index) {
-    build_index_cpp(copy);
+    build_index_cpp_by_ref(copy);
   }
   else {
     strip_index(copy);
@@ -28,15 +28,6 @@ DataFrame grouped_df_impl(DataFrame data, SymbolVector symbols, bool drop, bool
   return copy;
 }
 
-// [[Rcpp::export]]
-DataFrame as_regular_df(DataFrame df) {
-  DataFrame copy(shallow_copy(df));
-  SET_ATTRIB(copy, strip_group_attributes(df));
-  SET_OBJECT(copy, OBJECT(df));
-  set_class(copy, CharacterVector::create("data.frame"));
-  return copy;
-}
-
 // [[Rcpp::export]]
 DataFrame ungroup_grouped_df(DataFrame df) {
   DataFrame copy(shallow_copy(df));
