@@ -117,13 +117,13 @@ test_that("bind_rows ignores NULL", {
 })
 
 test_that("bind_rows only accepts data frames or named vectors", {
-  ll <- list(1:5, rlang::get_env())
+  ll <- list(1:5, env(a = 1))
   expect_error(
     bind_rows(ll),
     "Argument 1 must have names",
     fixed = TRUE
   )
-  ll <- list(tibble(a = 1:5), rlang::get_env())
+  ll <- list(tibble(a = 1:5), env(a = 1))
   expect_error(
     bind_rows(ll),
     "Argument 2 must be a data frame or a named atomic vector, not a environment",
